"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Icon = void 0;
var react_fontawesome_1 = require("@fortawesome/react-fontawesome");
var react_1 = __importDefault(require("react"));
/** Wraps a FontAwesome Icon into a React Component
 * - FontAwesome Pro requires a license to use pro icons, but [@cseitz](http://github.com/cseitz) is paying for one!
 * - This package and its subsequent icon packs are a slightly modified copy of the FontAwesome Pro icon packs!
 *
 * ### Icon Packs
 * All FontAwesome Pro icons are split into icon packs given the style of icon you want.
 * - Styles:
 * [`regular`](https://fontawesome.com/search?o=r&s=regular "▢ Regular icons with empty space in the middle."),
 * [`solid`](https://fontawesome.com/search?o=r&s=solid "■ Solid icons that fill their whole shape."),
 * [`light`](https://fontawesome.com/search?o=r&s=light "□ Regular icons with thin outlines"),
 * [`thin`](https://fontawesome.com/search?o=r&s=thin "▯ Regular icons with very thin outlines"),
 * [`brands`](https://fontawesome.com/search?o=r&f=brands "🌐 All the companies and other logos for stuff!"),
 * [`duotone`](https://fontawesome.com/search?o=r&s=duotone " Icons with two sections that can be individually colored."),
 * [`solid-sharp`](https://fontawesome.com/search?o=r&s=solid&f=sharp "▣ Solid icons without rounded corners, making them more blocky.")
 *
 * You can install packs via `npm install @cseitz/icons-[STYLE]`
 * ```bash
 * npm install @cseitz/icons @cseitz/icons-regular
 * ```
 *
 * Then, import the icon you want using the icon's __kebab case filepath__:
 * ```ts
 * import { faUserPlus } from '@cseitz/icons-regular/user-plus';
 * // OR, use the symlink generated by @cseitz/icons (PREFERRED USAGE)
 * import { faUserPlus } from '@cseitz/icons/regular/user-plus';
 * // FontAwesome's package import (REQUIRES PAID LICENSE NPM TOKEN TO INSTALL)
 * import { faUserPlus } from '@fortawesome/pro-regular-svg-icons';
 * ```
 *
 * Then, wrap it in the `Icon` component and you're good to go!
 * ```tsx
 * import { Icon } from '@cseitz/icons';
 * const UserPlusIcon = Icon(faUserPlus);
 * return <UserPlusIcon />
 * ```
 *
 *
 * ### Example
 * ```tsx
 * import { Icon } from '@cseitz/icons';
 * import { faGithub } from '@cseitz/icons/brands/github';
 * const GitHubIcon = Icon(faGithub);
 * return <GitHubIcon />
 * ```
 */
function Icon(icon) {
    return function (props) {
        var className = props.className, sx = props.sx, style = props.style, _a = props.scale, scale = _a === void 0 ? '1em' : _a, _props = __rest(props, ["className", "sx", "style", "scale"]);
        var def = (icon === null || icon === void 0 ? void 0 : icon.definition) || icon;
        return react_1.default.createElement(react_fontawesome_1.FontAwesomeIcon, __assign({ className: 'fa icon ' + (className || ''), icon: def, style: __assign(__assign({ height: scale, verticalAlign: '-0.125em' }, style), sx) }, _props));
    };
}
exports.Icon = Icon;
